@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005, 2006, 2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -23,14 +22,13 @@
 #
 import sys
 
-from qtpy import QtGui
-from qtpy import QtWidgets
+from qtpy import QtGui, QtWidgets
 
 ICONSDIR = '../vitables/icons/'
 big_icons = [('file_rw', 'The root node (read-write)'),
     ('file_ro', 'The root node (read-only)'),
     ('dbfilters', 'The root node of the Query Results file  '),
-    ('folder', 'A collapsed group '), 
+    ('folder', 'A collapsed group '),
     ('document-open-folder', 'An expanded group ')]
 small_icons = [('table', 'A table (heterogeneus dataset) '),
     ('array', 'A regular array (homogeneus dataset) '),
@@ -50,7 +48,6 @@ class Poster(QtWidgets.QMainWindow) :
     def __init__(self) :
         super(QtWidgets.QMainWindow, self).__init__()
         w = QtWidgets.QWidget(self)
-        l = QtWidgets.QGridLayout(w)
         self.setCentralWidget(w)
         self.makePoster()
 
@@ -64,7 +61,7 @@ class Poster(QtWidgets.QMainWindow) :
         for key in iconsDict.keys():
             for (name, caption) in iconsDict[key] :
                 pixmap = QtGui.QPixmap()
-                image_path = '{0}/{1}/{2}.png'.format(ICONSDIR, key, name)
+                image_path = f'{ICONSDIR}/{key}/{name}.png'
                 pixmap.load(image_path)
                 imLabel = QtWidgets.QLabel(widget)
                 imLabel.setPixmap(pixmap)
