@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -25,8 +24,9 @@ multidimensional cells.
 It also works to check views of multidimensional attributes.
 """
 
+import numpy as np
 import tables
-import numpy
+
 
 class Particle(tables.IsDescription):
     """Description of a table record."""
@@ -42,7 +42,7 @@ class Particle(tables.IsDescription):
 fileh = tables.open_file("MDobjects.h5", mode = "w")
 # Create the table with compression 'on' in order to reduce size as
 # much as possible
-table = fileh.create_table(fileh.root, 'table', Particle, "A table", 
+table = fileh.create_table(fileh.root, 'table', Particle, "A table",
     filters=tables.Filters(complevel=1))
 # Append several rows with default values
 for i in range(10):
@@ -54,27 +54,27 @@ atom1 = tables.IntAtom()
 shape1 = (2, 10, 10, 1)
 filters1 = tables.Filters(complevel=1)
 #(2, 10, 10, 3)
-array1 = fileh.create_carray(fileh.root, 'array1', atom1, shape1, 
+array1 = fileh.create_carray(fileh.root, 'array1', atom1, shape1,
     filters=filters1)
 atom2 = tables.FloatAtom()
 shape2 = (2, 10, 10, 3, 1)
 filters2 = tables.Filters(complevel=1)
 #(2, 10, 10, 3, 200)
-array2 = fileh.create_carray(fileh.root, 'array2', atom2, shape2, 
+array2 = fileh.create_carray(fileh.root, 'array2', atom2, shape2,
     filters=filters2)
 
 # Add multimensional attributes to the objects
 # Integers will go in /table
-table.attrs.MD1 = numpy.arange(5, dtype="int8")
-table.attrs.MD2 = numpy.arange(10, dtype="int64").reshape(2, 5)
+table.attrs.MD1 = np.arange(5, dtype="int8")
+table.attrs.MD2 = np.arange(10, dtype="int64").reshape(2, 5)
 
 # Complex will go in /array1
-array1.attrs.MD1 = numpy.arange(5, dtype="complex128")
-array1.attrs.MD2 = numpy.arange(10, dtype="complex128").reshape(2, 5)
+array1.attrs.MD1 = np.arange(5, dtype="complex128")
+array1.attrs.MD2 = np.arange(10, dtype="complex128").reshape(2, 5)
 
 # Strings will go in /array2
-array2.attrs.MD1 = numpy.array(['Hi', 'world!'], dtype='|S6')
-array2.attrs.MD2 = numpy.array([['Hi', 'world!'], 
+array2.attrs.MD1 = np.array(['Hi', 'world!'], dtype='|S6')
+array2.attrs.MD2 = np.array([['Hi', 'world!'],
     ['Hola', 'mon!']], dtype='|S4')
 
 fileh.close()
