@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -29,8 +28,9 @@ magnitude. F. Altet 2006-02-27
 """
 
 import time
-from numpy import arange
+
 import tables
+from numpy import arange
 
 t0 = time.time()
 
@@ -53,7 +53,7 @@ group = fileh.create_group(root, "Particles")
 # Now, create and fill the tables in Particles group
 filters = tables.Filters(complevel=1, complib='lzo', shuffle=1)
 nrows = 10**7
-table = fileh.create_table("/Particles", "TParticle", Particle, 
+table = fileh.create_table("/Particles", "TParticle", Particle,
     "Sample set of particles ", filters, expectedrows = nrows)
 
 # Number of rows in buffer
@@ -76,4 +76,4 @@ for i in range(0, nrows, nrowsbuf):
 fileh.close()
 
 tsec = round((time.time() - t0), 3)
-print('Last of the run: {0} s'.format(tsec))
+print(f'Last of the run: {tsec} s')
