@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -24,16 +23,16 @@
 
 """How to use the filenode module."""
 
-from tables.nodes import filenode
 import tables
+from tables.nodes import filenode
 
 h5file = tables.open_file('../misc/fnode.h5', 'w')
 fnode = filenode.new_node(h5file, where='/', name='fnode_test')
 
 counter = 0
 while counter < 100000:
-    l = "This is a line inserted programmatically at position {}\n".format(counter)
-    fnode.write(l.encode("utf-8"))
+    line = f"This is a line inserted programmatically at position {counter}\n"
+    fnode.write(line.encode("utf-8"))
     counter += 1
 
 fnode.close()
