@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -21,8 +20,7 @@
 
 "This creates an HDF5 file with a potentially large number of objects"
 
-import sys
-import numpy
+import numpy as np
 import tables
 
 filename = 'large_number_of_objects.h5'
@@ -41,7 +39,7 @@ nlevels, ngroups, ndatasets = (3, 10, 100)
 #nlevels, ngroups, ndatasets = (30, 10, 10)
 
 # Create an Array to save on disk
-a = numpy.array([-1, 2, 4], dtype=numpy.int16)
+a = np.array([-1, 2, 4], dtype=np.int16)
 
 group = fileh.root
 group2 = fileh.root
