@@ -4,15 +4,15 @@ import sys
 
 import pytest
 
-from qtpy import QtWidgets
 # from qtpy import QtCore
-from qtpy import QtGui
-# from qtpy.QtTest import QTest
+from qtpy import QtGui, QtWidgets
 
+# from qtpy.QtTest import QTest
 import vitables.utils
 
+
 @pytest.mark.usefixtures('launcher')
-class TestLogger(object):
+class TestLogger:
     @pytest.fixture()
     def config(self, launcher):
         cfg = launcher.vtapp_object.config
@@ -39,8 +39,7 @@ class TestLogger(object):
         organization = launcher.app.organizationName()
         product = launcher.app.applicationName()
         version = launcher.app.applicationVersion()
-        reg_path = 'HKEY_CURRENT_USER\\Software\\{0}\\{1}'.format(product,
-                                                                  version)
+        reg_path = f'HKEY_CURRENT_USER\\Software\\{product}\\{version}'
 
         if sys.platform.startswith('win'):
             assert config.organizationName() == product
