@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -29,14 +28,11 @@ __docformat__ = 'restructuredtext'
 
 import re
 
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
+from qtpy import QtCore, QtGui, QtWidgets
 
 import vitables.utils
 from vitables.vtsite import DOCDIR
 
-
 translate = QtWidgets.QApplication.translate
 
 
@@ -290,7 +286,7 @@ class HelpBrowserGUI(QtWidgets.QMainWindow) :
         controller, :meth:`vitables.docbrowser.helpbrowser.HelpBrowser`.
         """
 
-        self.combo_history.activated[str].connect(self.browser.displaySrc)
+        self.combo_history.activated[int].connect(self.browser.displaySrc)
 
         # This is the most subtle connection. It encompasses source
         # changes coming from anywhere, including slots (home, backward
@@ -316,13 +312,13 @@ class HelpBrowserGUI(QtWidgets.QMainWindow) :
 
         # Clear the current bookmarks from the Bookmarks menu
         for action in self.bookmarks_menu.actions():
-            if re.search("^(\s?\d)", action.text()):
+            if re.search(r"^(\s?\d)", action.text()):
                 self.bookmarks_menu.removeAction(action)
         # and refresh it
         index = 0
         for filepath in self.browser.bookmarks:
             index += 1
-            action = QtWidgets.QAction('{0:>2}. {1}'.format(index, filepath),
+            action = QtWidgets.QAction(f'{index:>2}. {filepath}',
                                     self.bookmarks_menu)
             action.setData(filepath)
             self.bookmarks_menu.addAction(action)
