@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -28,13 +27,10 @@ which is distributed along the source code in every supported platform.
 
 __docformat__ = 'restructuredtext'
 
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
+from qtpy import QtCore, QtWidgets
 
 import vitables.utils
-from vitables.docbrowser import bookmarksdlg
-from vitables.docbrowser import browsergui
+from vitables.docbrowser import bookmarksdlg, browsergui
 
 translate = QtWidgets.QApplication.translate
 
