@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -30,11 +29,11 @@ contains methods for editing nodes (but not data stored in nodes).
 import logging
 import os
 import uuid
-import vitables.utils
 
-from qtpy import QtCore
-from qtpy import QtWidgets
 import tables
+from qtpy import QtCore, QtWidgets
+
+import vitables.utils
 
 __docformat__ = 'restructuredtext'
 
@@ -106,7 +105,7 @@ class DBDoc(QtCore.QObject):
 
         try:
             h5file = tables.open_file(self.filepath, self.mode)
-        except IOError as inst:
+        except OSError as inst:
             log.error(translate('DBDoc', "{0}",
                                 'A logger error message').format(inst))
         except:
