@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -29,10 +28,10 @@ __docformat__ = 'restructuredtext'
 
 import vitables.utils
 from vitables.h5db import tnode_editor
-from vitables.nodeprops import nodeinfo
-from vitables.nodeprops import grouppropdlg
+from vitables.nodeprops import grouppropdlg, nodeinfo
 
-class GroupNode(object):
+
+class GroupNode:
     """
     A group node in the tree of databases model.
 
@@ -68,9 +67,9 @@ class GroupNode(object):
         parentpath = parent.nodepath
         if parentpath.endswith('/'):
             parentpath = parentpath[:-1]
-        self.nodepath = '{0}/{1}'.format(parentpath, name)
+        self.nodepath = f'{parentpath}/{name}'
         self.filepath = parent.filepath
-        self.as_record = '{0}->{1}'.format(self.filepath, self.nodepath)
+        self.as_record = f'{self.filepath}->{self.nodepath}'
         icons = vitables.utils.getIcons()
         self.closed_folder = icons['folder']
         self.open_folder = icons['document-open-folder']
