@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -30,10 +29,10 @@ import tables
 
 import vitables.utils
 from vitables.h5db import tlink_editor
-from vitables.nodeprops import nodeinfo
-from vitables.nodeprops import linkpropdlg
+from vitables.nodeprops import linkpropdlg, nodeinfo
 
-class LinkNode(object):
+
+class LinkNode:
     """
     A leaf node in the tree of databases model.
 
@@ -74,9 +73,9 @@ class LinkNode(object):
         parentpath = parent.nodepath
         if parentpath.endswith('/'):
             parentpath = parentpath[:-1]
-        self.nodepath = '{0}/{1}'.format(parentpath, name)
+        self.nodepath = f'{parentpath}/{name}'
         self.filepath = parent.filepath
-        self.as_record = '{0}'.format(self.node)
+        self.as_record = f'{self.node}'
 
         # Set the node icon
         icons = vitables.utils.getIcons()
