@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -25,9 +24,7 @@ Here is defined the NodeItemDelegate class.
 
 __docformat__ = 'restructuredtext'
 
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
+from qtpy import QtCore, QtWidgets
 
 import vitables.utils
 
@@ -93,12 +90,12 @@ class NodeItemDelegate(QtWidgets.QItemDelegate):
         #
         # Check if the nodename is already in use
         #
-        sibling = getattr(parent.node, '_v_children').keys()
+        sibling = parent.node._v_children.keys()
         # Note that current nodename is not allowed as new nodename.
         # Embedding it in the pattern makes unnecessary to pass it to the
         # rename dialog via method argument and simplifies the code
-        pattern = """(^{0}$)|""" \
-            """(^[a-zA-Z_]+[0-9a-zA-Z_ ]*)""".format(self.current_name)
+        pattern = f"""(^{self.current_name}$)|""" \
+            """(^[a-zA-Z_]+[0-9a-zA-Z_ ]*)"""
         info = [translate('NodeItemDelegate',
             'Renaming a node: name already in use',
             'A dialog caption'),
