@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -31,11 +30,7 @@ commands in the Logger.
     :Parameter parent: the parent widget of the Logger
 """
 
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
-
-import vitables.utils
+from qtpy import QtCore, QtGui, QtWidgets
 
 __docformat__ = 'restructuredtext'
 
@@ -126,7 +121,7 @@ class Logger(QtWidgets.QTextEdit):
         edit_menu.setObjectName('logger_context_menu')
 
         # QtGui.Qpalette.Window constant is 10
-        edit_menu.setStyleSheet("background-color: {0}".format(10))
+        edit_menu.setStyleSheet(f"background-color: {10}")
 
         self.copy_action = QtWidgets.QAction(
             translate('Logger', "&Copy", 'Logger menu entry'), self,
