@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -29,10 +28,8 @@ about the error and the dialog remains open so the user can fix her mistake.
 
 __docformat__ = 'restructuredtext'
 
+import numpy as np
 import tables
-import numpy
-
-from qtpy import QtGui
 from qtpy import QtWidgets
 
 import vitables.utils
@@ -111,18 +108,18 @@ def checkValue(dtype, str_value):
     """
 
     dtypes_map = {
-        'int8': numpy.int8, 'int16': numpy.int16,
-        'int32': numpy.int32, 'int64': numpy.int64,
-        'uint8': numpy.uint8, 'uint16': numpy.uint16,
-        'uint32': numpy.uint32, 'uint64': numpy.uint64,
-        'float32': numpy.float32, 'float64': numpy.float64,
+        'int8': np.int8, 'int16': np.int16,
+        'int32': np.int32, 'int64': np.int64,
+        'uint8': np.uint8, 'uint16': np.uint16,
+        'uint32': np.uint32, 'uint64': np.uint64,
+        'float32': np.float32, 'float64': np.float64,
         }
 
     # For Python objects and strings no overflow can occur
     if dtype not in dtypes_map:
         return str_value
 
-    new_array = numpy.array(str_value).astype(dtype)
+    new_array = np.array(str_value).astype(dtype)
     # Catches unexpected results from conversions
     # Examples: numpy.array('-23').astype('unint8') -> mismatch dtype
     # or numpy.array('99999').astype('int8') -> overflow
@@ -132,7 +129,7 @@ def checkValue(dtype, str_value):
     return str_value
 
 
-class AttrEditor(object):
+class AttrEditor:
     """
     Setup the attributes entered in the Properties dialog.
 
@@ -231,7 +228,7 @@ class AttrEditor(object):
         names_list = []
         for row in rows_range:
             name = self.edited_attrs[row][0]
-            if not name in names_list:
+            if name not in names_list:
                 names_list.append(name)
             else:
                 return (False,
@@ -242,7 +239,7 @@ class AttrEditor(object):
         # Check for dtype, range and syntax correctness of scalar attributes
         for row in rows_range:
             name, value, dtype, multidim = self.edited_attrs[row]
-            if multidim == True:
+            if multidim:
                 continue
             if dtype == 'python':
                 # Check the syntax of the Python expression
@@ -298,17 +295,17 @@ class AttrEditor(object):
             # Scalar attributes are stored as
             # numpy scalar arrays of the proper type
             name, value, dtype, multidim = self.edited_attrs[row]
-            if multidim == True:
+            if multidim:
                 continue
 
             if dtype == 'python':
-                value = eval('{0}'.format(value))
+                value = eval(f'{value}')
             elif dtype == 'bytes':
                 # Remove the prefix and enclosing quotes
                 value = value[2:-1]
-                value = numpy.array(value).astype(dtype)[()]
+                value = np.array(value).astype(dtype)[()]
             else:
-                value = numpy.array(value).astype(dtype)[()]
+                value = np.array(value).astype(dtype)[()]
 
             # Updates the ASI
             try:
