@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -26,9 +25,7 @@ A form with tables.Leaf information collected by the
 
 import os.path
 
-from qtpy import QtGui
-from qtpy import QtWidgets
-
+from qtpy import QtGui, QtWidgets
 from qtpy.uic import loadUiType
 
 import vitables.utils
@@ -106,9 +103,8 @@ class LeafPropPage(QtWidgets.QWidget, Ui_LeafPropPage):
             # The Table's fields description
             table.horizontalHeader().setSectionResizeMode(
                 QtWidgets.QHeaderView.Stretch)
-            # QtGui.QPalette.Window constant is 10
-            bg_name = table.palette().brush(10).color().name()
-            table.setStyleSheet("background-color: {0}".format(bg_name))
+            bg_name = table.palette().brush(QtGui.QPalette.Window).color().name()
+            table.setStyleSheet(f"background-color: {bg_name}")
             self.fields_model = QtGui.QStandardItemModel()
             self.fields_model.setHorizontalHeaderLabels(
                 [translate('LeafPropPage', 'Field name',
