@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -26,9 +25,7 @@ This module displays in a dialog the link information collected by the
 
 import os.path
 
-from qtpy import QtGui
 from qtpy import QtWidgets
-
 from qtpy.uic import loadUiType
 
 import vitables.utils
