@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -27,9 +26,8 @@ __docformat__ = 'restructuredtext'
 
 import os.path
 
-import vitables.utils
 
-class NodeInfo(object):
+class NodeInfo:
     """Collects information about a given node.
 
     The following data and metadata can be collected:
@@ -129,15 +127,15 @@ class NodeInfo(object):
         gbytes = mbytes/1024
         tbytes = gbytes/1024
         if kbytes < 1:
-            size = '{0:.0f} bytes'.format(n_bytes)
+            size = f'{n_bytes:.0f} bytes'
         elif mbytes < 1:
-            size = '{0:.1f} KB'.format(kbytes)
+            size = f'{kbytes:.1f} KB'
         elif gbytes < 1:
-            size = '{0:.1f} MB'.format(mbytes)
+            size = f'{mbytes:.1f} MB'
         elif tbytes < 1:
-            size = '{0:.1f} GB'.format(gbytes)
+            size = f'{gbytes:.1f} GB'
         else:
-            size = '{0:.1f} TB'.format(tbytes)
+            size = f'{tbytes:.1f} TB'
         return size
 
     size = property(fget=_size)
