@@ -1,5 +1,5 @@
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -18,18 +18,18 @@
 
 """This is the launcher script for the ViTables application."""
 
-import sys
-import locale
 import argparse
-import os.path
+import atexit
+import locale
 import logging
+import os.path
+import sys
 import traceback
 
-import qtpy.QtCore as qtcore
-from qtpy import QtWidgets
+from qtpy import QtCore, QtWidgets
 
-from vitables.vtapp import VTApp
 from vitables.preferences import vtconfig
+from vitables.vtapp import VTApp
 
 __docformat__ = 'restructuredtext'
 
@@ -42,7 +42,7 @@ _FILE_LOG_FORMAT = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
 _I18N_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'i18n')
 
 
-_uncaught_exception_logger = logging.getLogger('vitables')
+_uncaught_exception_logger = logging.getLogger('uncaught_logger')
 
 
 def _uncaught_exception_hook(type_, value, tb):
@@ -59,7 +59,7 @@ def _check_versions():
     import tables
     if tables.__version__ < '3.0':
         sys.exit('FATAL: PyTables version 3.0 or above is required, '
-                 'installed version is {}'.format(tables.__version__))
+                 f'installed version is {tables.__version__}')
 
 
 def _set_credentials(app):
@@ -87,8 +87,8 @@ def _set_locale(app):
     locale.setlocale(locale.LC_ALL, '')
     locale.setlocale(locale.LC_NUMERIC, 'C')
 
-    locale_name = qtcore.QLocale.system().name()
-    translator = qtcore.QTranslator()
+    locale_name = QtCore.QLocale.system().name()
+    translator = QtCore.QTranslator()
     if translator.load('vitables_' + locale_name, _I18N_PATH):
         app.installTranslator(translator)
     return translator
@@ -103,7 +103,7 @@ def _parse_command_line():
     # Options for the default group
     parser.add_argument(
         '--version', action='version',
-        version='%(prog)s {}'.format(vtconfig.getVersion()))
+        version=f'%(prog)s {vtconfig.getVersion()}')
     # Options for opening files
     h5files_group.add_argument(
         '-m', '--mode', choices=['r', 'a'], metavar='MODE',
@@ -129,7 +129,7 @@ def _parse_command_line():
 
 
 def _setup_logger(args):
-    """Setup logger output format, level and output file.
+    """Setup root logger output format, level and output file.
 
     Stderr logger is added to handle error that raise before the gui
     is launched. It better be removed before event loop starts.
@@ -154,11 +154,52 @@ def _setup_logger(args):
         logger.setLevel(_VERBOSITY_LOGLEVEL_DICT[args.verbose])
     else:
         logger.setLevel(logging.ERROR)
-        logger.error('Invalid verbosity level: {}, error level '
-                     'set to ERROR'.format(args.verbose))
+        logger.error(f'Invalid verbosity level: {args.verbose}, error level '
+                     'set to ERROR')
     return logger, temporary_stderr_handler
 
 
+def _close_open_files(verbose=None):
+    """Close all open files in the current HDF5 library.
+
+    This cleanup function is useful to avoid UnclosedFileWarning messages when
+    ViTables quits. It is called by the atexit module.
+
+    """
+
+    import tables
+
+    open_files = tables.file._open_files
+
+    are_open_files = len(open_files) > 0
+
+    if verbose and are_open_files:
+        sys.stderr.write("Closing remaining open files:")
+
+    if tables.__version__ >= "3.1.0":
+        # make a copy of the open_files.handlers container for the iteration
+        handlers = list(open_files.handlers)
+    else:
+        # for older versions of pytables, setup the handlers list from the
+        # keys
+        keys = open_files.keys()
+        handlers = []
+        for key in keys:
+            handlers.append(open_files[key])
+
+    for fileh in handlers:
+        if verbose:
+            sys.stderr.write(f"{fileh.filename}...")
+
+        fileh.close()
+
+        if verbose:
+            sys.stderr.write("done")
+
+    if verbose and are_open_files:
+        sys.stderr.write("\n")
+
+
 def gui():
     """The application launcher.
 
@@ -171,12 +212,13 @@ def gui():
     _set_credentials(app)
     translator = _set_locale(app)  # must not be destroyed before app quits
     args = _parse_command_line()
-    logger, console_log_handler = _setup_logger(args)
+    root_logger, console_log_handler = _setup_logger(args)
     vtapp = VTApp(mode=args.mode, dblist=args.dblist, h5files=args.h5file)
     vtapp.gui.show()
-    logger.removeHandler(console_log_handler)
+    root_logger.removeHandler(console_log_handler)
     app.exec_()
 
 
 if __name__ == '__main__':
+    atexit.register(_close_open_files, False)
     gui()
