@@ -1,5 +1,5 @@
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -21,25 +21,22 @@ This is the utilities module. It contains functions that perform
 tasks that are required at several parts of the application.
 """
 
-import sys
-import os
-import traceback
-import locale
-import re
-import logging
 import collections
 import functools
+import locale
+import logging
+import os
+import re
+import sys
+import traceback
 
-import numpy
+import numpy as np
 import tables
-
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
+from qtpy import QtCore, QtGui, QtWidgets
 from qtpy.QtWidgets import QFileDialog
 
-import vitables.vtwidgets.renamedlg as renamedlg
 from vitables.vtsite import ICONDIR
+from vitables.vtwidgets import renamedlg
 
 __docformat__ = 'restructuredtext'
 
@@ -209,10 +206,10 @@ def addActions(target, actions, actions_dict):
     for action in actions:
         if action is None:
             target.addSeparator()
-        elif isinstance(action, QtWidgets.QMenu):
-            target.addMenu(action)
+        elif type(action) is str:
+             target.addAction(actions_dict[action])
         else:
-            target.addAction(actions_dict[action])
+            target.addMenu(action)
 
 
 def addToLeafContextMenu(actions, enable_function=None):
@@ -331,7 +328,7 @@ def checkFileExtension(filepath):
     :Returns: the filepath with the proper extension.
     """
 
-    if not re.search('\.(.+)$', os.path.basename(filepath)):
+    if not re.search(r"\.(\w+)$", os.path.basename(filepath)):
         ext = '.h5'
         filepath = filepath + ext
     return filepath
@@ -453,13 +450,13 @@ def formatArrayContent(content):
     :Parameter content: the ``numpy`` array contained in the view cell
     """
 
-    if isinstance(content, numpy.string_):
+    if isinstance(content, np.bytes_):
         try:
             return content.decode(DEFAULT_ENCODING)
         except UnicodeDecodeError:
             pass
 
-    ret = numpy.array2string(content, separator=',')
+    ret = np.array2string(content, separator=',')
     return ret
 
 
@@ -513,7 +510,7 @@ def formatExceptionInfo(limit=1):
 
     :Parameter limit: the number of stack trace entries to be printed
     """
-    log.error('{0}'.format(traceback.format_exc(limit)))
+    log.error(f'{traceback.format_exc(limit)}')
 
 #
 # Path related functions
@@ -655,11 +652,10 @@ def isDataSourceReadable(leaf):
         readable = False
         log.error(
             """Problems reading records. The dataset seems to be """
-            """compressed with the {0} library. Check that it is """
-            """installed in your system, please.\n{1}""".format(
-                leaf.filters.complib, e.message))
+            f"""compressed with the {leaf.filters.complib} library. Check that it is """
+            f"""installed in your system, please.\n{e.message}""")
     except ValueError as e:
         readable = False
-        log.error('Data read error: {}'.format(e.message))
+        log.error(f'Data read error: {e.message}')
     finally:
         return readable
