@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -25,16 +24,13 @@ toolbars, statusbars and `QActions` bound to both menus and toolbars.
 """
 
 import logging
-from vitables.calculator import calculator
+
+from qtpy import QtCore, QtGui, QtWidgets
+
 import vitables.utils
-
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
-
-import vitables.h5db.dbstreemodel as dbstreemodel
-import vitables.h5db.dbstreeview as dbstreeview
-import vitables.logger as logger
+from vitables import logger
+from vitables.calculator import calculator
+from vitables.h5db import dbstreemodel, dbstreeview
 
 __docformat__ = 'restructuredtext'
 
@@ -109,6 +105,7 @@ class VTGUI(QtWidgets.QMainWindow):
         self.logger_dock.setWidget(self.logger)
         # add self.logger as handler of main logger object
         vitables_logger = logging.getLogger('vitables')
+        vitables_logger.setLevel(logging.ERROR)
         stream_handler = logging.StreamHandler(self.logger)
         stream_handler.setFormatter(logging.Formatter(_GUI_LOG_FORMAT))
         vitables_logger.addHandler(stream_handler)
@@ -804,7 +801,7 @@ class VTGUI(QtWidgets.QMainWindow):
         for item in self.vtapp.config.recent_files:
             index += 1
             (mode, filepath) = item.split('#@#')
-            action = QtWidgets.QAction('{0:>2} {1}.'.format(index, filepath),
+            action = QtWidgets.QAction(f'{index:>2} {filepath}.',
                                        self,
                                        triggered=self.vtapp.openRecentFile)
             action.setData(item)
@@ -853,7 +850,7 @@ class VTGUI(QtWidgets.QMainWindow):
         for window in windows_list:
             title = window.windowTitle()
             if counter < 10:
-                action = wmenu.addAction("&{0:d} {1}".format(counter, title))
+                action = wmenu.addAction(f"&{counter:d} {title}")
                 wmenu.action_group.addAction(action)
             elif counter == 10:
                 wmenu.addSeparator()
