@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -143,28 +142,33 @@ class DataFrameModel(QtCore.QAbstractTableModel):
 
         super(DataFrameModel, self).__init__(parent)
 
-    def columnCount(self, index=QtCore.QModelIndex()):
+    def columnCount(self, parent=None):
         """
         The total number of columns, or number of children for the given index.
 
-        :param index:
-            Overrides should return 0 for valid indices (if no children exist)
+        :param parent:
+            Overrides should return 0 for valid indices (because no children exist)
             or the number of the total *columns* (including row labels) exposed
             by the model.
         """
-        return 0 if index.isValid() else self.numcols + self._nheaders[1]
 
-    def rowCount(self, index=QtCore.QModelIndex()):
+        if parent is None:
+            parent = QtCore.QModelIndex()
+        return 0 if parent.isValid() else self.numcols + self._nheaders[1]
+
+    def rowCount(self, parent=None):
         """
-        The total number of rows, or number of children for the given index.
+        The total number of rows, or number of children under the given parent.
 
-        :param index:
-            Overrides should return 0 for valid indices (if no children exist)
+        :param parent:
+            Overrides should return 0 for valid indices (because no children exist)
             or the number of the total *rows* (including column labels) exposed
             by the model.
         """
 
-        return 0 if index.isValid() else self.numrows + self._nheaders[0]
+        if parent is None:
+            parent = QtCore.QModelIndex()
+        return 0 if parent.isValid() else self.numrows + self._nheaders[0]
 
     def loadData(self, start, length):
         """Load the model with fresh chunk from the underlying leaf.
@@ -180,8 +184,7 @@ class DataFrameModel(QtCore.QAbstractTableModel):
         stop = min(start + length, self.leaf_numrows)
         if stop < start:
             log.debug(
-                'Chunk: number of rows %s, first row %s, last row {2}',
-                self.numrows, start, stop
+                f"Chunk: number of rows {self.numrows}, first row {start}, last row {stop}"
             )
 
         # Ensure that the whole buffer will be filled.
@@ -293,9 +296,7 @@ class DataFrameModel(QtCore.QAbstractTableModel):
         return None  # Disable zoom.
 
     def to_csv(self, filepath, add_header):
-        import io
-
-        with io.open(filepath, 'wt', encoding='utf-8') as fd:
+        with open(filepath, 'w', encoding='utf-8') as fd:
             chunks = iter(self._hstore.select(self._pgroup, iterator=True))
             df = next(chunks)
             df.to_csv(fd, header=add_header)
