@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -29,11 +28,9 @@ should be rendered in the standard way. If it is not then it should always be
 rendered unselected.
 """
 
-__docformat__ = 'restructuredtext'
+from qtpy import QtCore, QtGui, QtWidgets
 
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
+__docformat__ = 'restructuredtext'
 
 class LeafDelegate(QtWidgets.QStyledItemDelegate):
     """
