@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -34,13 +33,9 @@ tabular way:
 
 __docformat__ = 'restructuredtext'
 
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
-
-import vitables.vttables.leaf_delegate as leaf_delegate
-import vitables.vttables.scrollbar as scrollbar
+from qtpy import QtCore, QtGui, QtWidgets
 
+from vitables.vttables import leaf_delegate, scrollbar
 
 _aiv = QtWidgets.QAbstractItemView
 
@@ -92,7 +87,7 @@ class LeafView(QtWidgets.QTableView):
         font = self.vheader.font()
         font.setBold(True)
         fmetrics = QtGui.QFontMetrics(font)
-        max_width = fmetrics.width(" {0} ".format(str(leaf_numrows)))
+        max_width = fmetrics.width(f" {leaf_numrows!s} ")
         self.vheader.setMinimumWidth(max_width)
         self.vheader.setSectionsClickable(True)
 
@@ -111,8 +106,11 @@ class LeafView(QtWidgets.QTableView):
             self.tricky_vscrollbar.actionTriggered.connect(
                 self.navigateWithMouse)
 
-        ## Instead of invoking updateView().
-        self.setSpan(0, 0, *tmodel.get_corner_span())
+        (row_span, col_span) = tmodel.get_corner_span()
+        # Check the left corner span to avoid the annoying console message
+        # QTableView::setSpan: single cell span won't be added
+        if (row_span > 1) | (col_span > 1):
+            self.setSpan(0, 0, row_span, col_span)
 
     def mapSlider2Leaf(self):
         """Setup the interval size.
@@ -169,7 +167,11 @@ class LeafView(QtWidgets.QTableView):
         bottom_right = tmodel.index(tmodel.numrows - 1,
                                     tmodel.numcols - 1)
         self.dataChanged(top_left, bottom_right)
-        self.setSpan(0, 0, *tmodel.get_corner_span())
+        # Check the left corner span to avoid the annoying console message
+        # QTableView::setSpan: single cell span won't be added
+        (row_span, col_span) = tmodel.get_corner_span()
+        if (row_span > 1) | (col_span > 1):
+            self.setSpan(0, 0, row_span, col_span)
 
     def navigateWithMouse(self, slider_action):
         """Navigate the view with the mouse.
@@ -619,8 +621,7 @@ class LeafView(QtWidgets.QTableView):
             self.updateView()
             # The position of the new current row
             row = dataset_row - model.start - 1
-            if row < 0:
-                row = 0
+            row = max(row, 0)
             index = model.index(row, buffer_column)
             self.setCurrentIndex(index)
             self.scrollTo(index,
@@ -650,8 +651,7 @@ class LeafView(QtWidgets.QTableView):
             self.updateView()
             # The position of the new current row
             row = dataset_row - model.start - page_step - 1
-            if row < 0:
-                row = 0
+            row = max(row, 0)
             index = model.index(row, buffer_column)
             self.setCurrentIndex(index)
             self.scrollTo(index,
@@ -682,8 +682,7 @@ class LeafView(QtWidgets.QTableView):
             self.updateView()
             # The position of the new current row
             row = dataset_row - model.start + 1
-            if row > table_rows - 1:
-                row = table_rows - 1
+            row = min(row, table_rows - 1)
             index = model.index(row, buffer_column)
             self.setCurrentIndex(index)
             self.scrollTo(index,
@@ -714,8 +713,7 @@ class LeafView(QtWidgets.QTableView):
             self.updateView()
             # The position of the new current row
             row = dataset_row - model.start + page_step + 1
-            if row > table_rows - 1:
-                row = table_rows - 1
+            row = min(row, table_rows - 1)
             index = model.index(row, buffer_column)
             self.setCurrentIndex(index)
             self.scrollTo(index,
