@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -28,9 +27,7 @@ is being renamed.
 
 import os.path
 
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
+from qtpy import QtCore, QtGui, QtWidgets
 from qtpy.uic import loadUiType
 
 import vitables.utils
@@ -84,14 +81,14 @@ class InputNodeName(QtWidgets.QDialog, Ui_InputNodenameDialog):
             action, QtWidgets.QDialogButtonBox.AcceptRole)
 
         # Setup a validator for checking the entered node name
-        validator = QtGui.QRegExpValidator(self)
-        pattern = QtCore.QRegExp("[a-zA-Z_]+[0-9a-zA-Z_ ]*")
-        validator.setRegExp(pattern)
+        validator = QtGui.QRegularExpressionValidator(self)
+        pattern = QtCore.QRegularExpression("[a-zA-Z_]+[0-9a-zA-Z_ ]*")
+        validator.setRegularExpression(pattern)
         self.valueLE.setValidator(validator)
 
         if default_value:
             self.valueLE.setText(default_value)
-            
+
         # Make sure that buttons are in the proper activation state
         self.valueLE.textChanged.emit(self.valueLE.text())
 
