@@ -1,8 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #       Copyright (C) 2005-2007 Carabos Coop. V. All rights reserved
-#       Copyright (C) 2008-2019 Vicent Mas. All rights reserved
+#       Copyright (C) 2008-2024 Vicent Mas. All rights reserved
 #
 #       This program is free software: you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -23,14 +22,12 @@
 Display recursively the content of a given cell of a view.
 """
 
-__docformat__ = 'restructuredtext'
-
-from qtpy import QtCore
-from qtpy import QtGui
-from qtpy import QtWidgets
+from qtpy import QtCore, QtWidgets
 
 import vitables.utils
 
+__docformat__ = 'restructuredtext'
+
 def getArrayDimensions(shape):
     """
     Get the dimensions of the grid where the cell will be zoomed.
@@ -156,13 +153,13 @@ class ZoomCell(QtWidgets.QMdiSubWindow):
         else:
             for section in range(0, ncols):
                 item = QtWidgets.QTableWidgetItem()
-                item.setText('{0}'.format(section))
+                item.setText(f'{section}')
                 self.grid.setHorizontalHeaderItem(section, item)
 
         # Setup grid vertical header
         for section in range(0,nrows):
             item = QtWidgets.QTableWidgetItem()
-            item.setText('{0}'.format(section))
+            item.setText(f'{section}')
             self.grid.setVerticalHeaderItem(section, item)
 
         # Fill the grid
@@ -319,8 +316,7 @@ class ZoomCell(QtWidgets.QMdiSubWindow):
 
         # Get caption
         if self.field_names:
-            caption = '{0}: {1}[{2}]'.format(self.title,
-                self.field_names[col], row)
+            caption = f'{self.title}: {self.field_names[col]}[{row}]'
         else:
-            caption = '{0}: ({1}, {2})'.format(self.title, row, col)
+            caption = f'{self.title}: ({row}, {col})'
         ZoomCell(cell, caption, self.workspace, self.dbt_leaf)
